@@ -2,13 +2,16 @@ from .strong_sort.utils.parser import get_config
 from .strong_sort.strong_sort import StrongSORT
 from .ocsort.ocsort import OCSort
 from .bytetrack.byte_tracker import BYTETracker
-
+import os
+import sys
 
 def create_tracker(tracker_type, appearance_descriptor_weights, device, half):
     if tracker_type == 'strongsort':
         # initialize StrongSORT
         cfg = get_config()
-        cfg.merge_from_file('trackers/strong_sort/configs/strong_sort.yaml')
+        parent_dir = os.path.dirname(__file__)
+        config_path = os.path.join(parent_dir, 'strong_sort/configs/strong_sort.yaml')
+        cfg.merge_from_file(config_path)
 
         strongsort = StrongSORT(
             appearance_descriptor_weights,
