@@ -12,7 +12,7 @@ from .sort.tracker import Tracker
 
 from .reid_multibackend import ReIDDetectMultiBackend
 
-from person_counter.yolov5.utils.general import xyxy2xywh
+from ...yolov5.utils.general import xyxy2xywh
 
 
 class StrongSORT(object):
